@@ -1,6 +1,6 @@
 import os
 
-from gitbucket import config
+import config
 
 default_war_path = '/opt'
 
