@@ -24,7 +24,7 @@ class GitBucketControl:
         self.systemd.enable()
         self.systemd.start()
 
-        gb = GitBucket('http://localhost:{}'.format(PORT), USER_URL)
+        gb = GitBucket('http://127.0.0.1:{}'.format(PORT), USER_URL)
         gb.wait(timeout=180, check_period=5)
         if login == DEFAULT_LOGIN:
             gb.change_password(DEFAULT_LOGIN, DEFAULT_PASSWORD, password)
